@@ -1,5 +1,6 @@
-import os
 import abc
+import os
+
 import pandas as pd
 
 # Global archimedes config
@@ -8,6 +9,9 @@ ARCHIMEDES_CONF_DIR = os.path.join(USER_HOME_DIR, ".archimedes")
 
 
 def get_environment():
+    """
+    Returns the environment identifier for the application
+    """
     env = os.environ.get("ARCHIMEDES_ENVIRONMENT")
     if env is None:
         env = os.environ.get("ENVIRONMENT", "prod")
@@ -15,6 +19,9 @@ def get_environment():
 
 
 def get_msal_path():
+    """
+    Returns the path where MSAL cache file is stored
+    """
     msal_path = os.path.join(ARCHIMEDES_CONF_DIR, f"msal-{get_environment()}.cache.bin")
     return msal_path
 
@@ -35,22 +42,33 @@ ARCHIMEDES_API_CONFIG = {
 }
 
 
-class ArchimedesConstants:
+class ArchimedesConstants:  # pylint:disable=too-few-public-methods
+    """
+    Defines the default constraints for the application
+    """
+
     DATE_LOW = pd.to_datetime("1900-01-01T00:00:00+00:00")
     DATE_HIGH = pd.to_datetime("2090-01-01T00:00:00+00:00")
 
 
 class InvalidEnvironmentException(Exception):
-    pass
+    """
+    Exception to be raised when the environment to be
+    """
 
 
-class ApiConfig(abc.ABC):
+class ApiConfig(abc.ABC):  # pylint:disable=too-few-public-methods
+    """
+    Base class for API config
+    """
+
     def __init__(self, env):
         self.config = ARCHIMEDES_API_CONFIG
-        if env not in self.config.keys():
+        if env not in self.config:
             raise InvalidEnvironmentException(
                 f"Invalid environment {env}, "
-                f"supported values are {', '.join([str(key) for key in self.config.keys()])}"
+                f"supported values are "
+                f"{', '.join([str(key) for key in self.config])}"
             )
         self.environment = env.lower()
 
@@ -60,8 +78,17 @@ class ApiConfig(abc.ABC):
 
 
 def get_api_config():
+    """
+    Returns API configuration
+    """
     return ApiConfig(get_environment())
 
 
 def get_api_base_url(api_version: int) -> str:
+    """
+    Returns base url of the api
+
+    Parameters:
+        api_version: Version of the API
+    """
     return f"{get_api_config().url}/v{api_version}"
